#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Jussi Määttä, 2014

# Encode the input stream (allowed characters: a-z and ' ')
# using a given codebook that uses two-character symbols and
# appends '#' to the input if it has an odd number of characters.
# The codebook is assumed to contain codes for all symbols
# occurring in the input.
#
# Usage:
#
#     encode.py codebook.json < input > output
#
# where codebook.json contains the output of build_codebook.py.

import json
import sys

codebook = json.loads(open(sys.argv[1]).read())

input_string = sys.stdin.read()

for symbol in [ input_string[i:i+2] for i in range(0, len(input_string), 2) ]:
    if len(symbol) == 1:
        symbol = symbol + "#"

    if symbol in codebook:
        sys.stdout.write(codebook[symbol])
    else:
        raise RuntimeError('Unknown symbol: ' + symbol)